==> owncloud-10.0.8.tar.bz2: owncloud/core/l10n/lt_LT.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Pasirinkite failą.",
    "File is too big" : "Per didelis failas",
    "Invalid file provided" : "Netinkamas failas",
    "No image or file provided" : "Nenurodytas paveikslėlis ar failas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Netinkamas paveikslėlis",
    "No temporary profile picture available, try again" : "Nėra laikino profilio paveikslėlio, bandykite dar kartą",
    "No crop data provided" : "Nenurodyti apkirpimo duomenys",
    "%s password reset" : "%s slaptažodžio atnaujinimas",
    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atkūrimo laiško, susisiekite su administratoriumi.",
    "Couldn't send mail to following users: %s " : "Nepavyko nusiųsti el. pašto šiems naudotojams: %s ",
    "Preparing update" : "Ruošiamasi atnaujinimui",
    "Repair warning: " : "Taisymo perspėjimas:",
    "Repair error: " : "Taisymo klaida:",
    "Turned on maintenance mode" : "Įjungta priežiūros veiksena",
    "Turned off maintenance mode" : "Išjungta priežiūros veiksena",
    "Maintenance mode is kept active" : "Priežiūros veiksena yra aktyvi",
    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
    "Updated database" : "Atnaujinta duomenų bazė",
    "Checked database schema update" : "Tikrinama duomenų bazės struktūra",
    "Checked database schema update for apps" : "Tikrinama duomenų bazės struktūra įskiepiams",
    "Updated \"%s\" to %s" : "Atnaujinta \"%s\" į %s",
    "Following apps have been disabled: %s" : "Išjungti įskiepiai: %s",
    "Already up to date" : "Jau naujausia",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sun." : "Sk.",
    "Mon." : "Pr.",
    "Tue." : "An.",
    "Wed." : "Tr.",
    "Thu." : "Kt.",
    "Fri." : "Pn.",
    "Sat." : "Št.",
    "Su" : "S",
    "Mo" : "P",
    "Tu" : "A",
    "We" : "T",
    "Th" : "K",
    "Fr" : "Pn",
    "Sa" : "Š",
    "January" : "Sausis",
    "February" : "Vasaris",
    "March" : "Kovas",
    "April" : "Balandis",
    "May" : "Gegužė",
    "June" : "Birželis",
    "July" : "Liepa",
    "August" : "Rugpjūtis",
    "September" : "Rugsėjis",
    "October" : "Spalis",
    "November" : "Lapkritis",
    "December" : "Gruodis",
    "Jan." : "Sau.",
    "Feb." : "Vas.",
    "Mar." : "Kov.",
    "Apr." : "Bal.",
    "May." : "Geg.",
    "Jun." : "Bir.",
    "Jul." : "Lie.",
    "Aug." : "Rugp.",
    "Sep." : "Rugs.",
    "Oct." : "Spa.",
    "Nov." : "Lap.",
    "Dec." : "Groud.",
    "Settings" : "Nustatymai",
    "Saving..." : "Saugoma...",
    "Dismiss" : "Atmesti",
    "seconds ago" : "prieš sekundę",
    "I know what I'm doing" : "Aš žinau ką darau",
    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas, susisiekite su administratoriumi.",
    "No" : "Ne",
    "Yes" : "Taip",
    "Choose" : "Pasirinkite",
    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
    "Ok" : "Gerai",
    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
    "read-only" : "tik skaitymui",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failas konfliktuoja","{count} failai konfliktuoja","{count} failų konfliktų"],
    "One file conflict" : "Vienas failo konfliktas",
    "New Files" : "Naujas failas",
    "Already existing files" : "Egzistuojantys failai",
    "Which files do you want to keep?" : "Kuriuos failus norite laikyti?",
    "If you select both versions, the copied file will have a number added to its name." : "Jei pasirenkate abi versijas, nukopijuotas failas turės pridėtą numerį pavadinime.",
    "Cancel" : "Atšaukti",
    "Continue" : "Tęsti",
    "(all selected)" : "(visi pažymėti)",
    "({count} selected)" : "({count} pažymėtų)",
    "Error loading file exists template" : "Klaida įkeliant esančių failų ruošinį",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Shared" : "Dalinamasi",
    "Error" : "Klaida",
    "Error while sharing" : "Klaida, dalijimosi metu",
    "Error while unsharing" : "Klaida, kai atšaukiamas dalijimasis",
    "The public link will expire no later than {days} days after it is created" : "Vieša nuoroda galios ne mažiau kaip {days} dienas nuo sukūrimo",
    "Set expiration date" : "Nustatykite galiojimo laiką",
    "Expiration" : "Galiojimo laikas",
    "Expiration date" : "Galiojimo laikas",
    "Link" : "Nuoroda",
    "Edit" : "Redaguoti",
    "Remove" : "Pašalinti",
    "Copied!" : "Nukopijuota!",
    "Choose a password for the public link" : "Viešos nuorodos slaptažodis",
    "Password required" : "Reikalingas slaptažodis",
    "Filename" : "Failo pavadinimas",
    "Password" : "Slaptažodis",
    "Name" : "Pavadinimas",
    "Allow editing" : "Leisti redaguoti",
    "Save" : "Išsaugoti",
    "Sending ..." : "Siunčiama...",
    "Email sent" : "Laiškas išsiųstas",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send link via email" : "Siųsti nuorodą el. paštu",
    "Shared with you and the group {group} by {owner}" : "Pasidalino su Jumis ir {group} grupe {owner}",
    "Shared with you by {owner}" : "Pasidalino su Jumis {owner}",
    "group" : "grupė",
    "remote" : "nutolęs",
    "notify by email" : "pranešti el. paštu",
    "Unshare" : "Nebesidalinti",
    "can share" : "gali dalintis",
    "can edit" : "gali redaguoti",
    "create" : "sukurti",
    "change" : "keisti",
    "delete" : "ištrinti",
    "access control" : "priėjimo kontrolė",
    "Share" : "Dalintis",
    "Public Links" : "Viešos nuorodos",
    "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Dalintis su vartotoju kitame ownCloud debesyje, sintaksė vartotojas@example.com/owncloud",
    "Share with users…" : "Dalintis su vartotojais...",
    "Share with users, groups or remote users…" : "Dalintis su vartotojais, grupėmis, ar nutolusiais vartotojais...",
    "Share with users or groups…" : "Dalintis su vartotojais arba grupėmis...",
    "Share with users or remote users…" : "Dalintis su vartotojais ar nutolusiais vartotojais...",
    "Warning" : "Įspėjimas",
    "Delete" : "Ištrinti",
    "Rename" : "Pervadinti",
    "The object type is not specified." : "Objekto tipas nenurodytas.",
    "Enter new" : "Įveskite naują",
    "Add" : "Pridėti",
    "Edit tags" : "Redaguoti žymes",
    "Error loading dialog template: {error}" : "Klaida įkeliant dialogo ruošinį: {error}",
    "No tags selected for deletion." : "Trynimui nepasirinkta jokia žymė.",
    "Hello world!" : "Sveikas pasauli!",
    "sunny" : "saulėta",
    "Please reload the page." : "Prašome perkrauti puslapį.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Atnaujinimas buvo nesėkmingas. PApie tai prašome pranešti the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud bendruomenei</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Atnaujinimas buvo sėkmingas. Nukreipiame į jūsų ownCloud.",
    "Personal" : "Asmeniniai",
    "Users" : "Vartotojai",
    "Apps" : "Programos",
    "Admin" : "Administravimas",
    "Help" : "Pagalba",
    "Access forbidden" : "Priėjimas draudžiamas",
    "File not found" : "Failas nerastas",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Labas,\n\nInformuojame, kad %s pasidalino su Jumis %s.\nPažiūrėti tai: %s\n",
    "The share will expire on %s." : "Bendrinimo laikas baigsis %s.",
    "Cheers!" : "Sveikinimai!",
    "Internal Server Error" : "Vidinė serverio klaida",
    "Technical details" : "Techniniai duomenys",
    "Remote Address: %s" : "Nuotolinis adresas: %s",
    "Request ID: %s" : "Užklausos ID: %s",
    "Type: %s" : "Tipas: %s",
    "Code: %s" : "Kodas: %s",
    "File: %s" : "Failas: %s",
    "Trace" : "Sekti",
    "Create an <strong>admin account</strong>" : "Sukurti <strong>administratoriaus paskyrą</strong>",
    "Username" : "Prisijungimo vardas",
    "Storage & database" : "Saugykla ir duomenų bazė",
    "Data folder" : "Duomenų katalogas",
    "Configure the database" : "Nustatyti duomenų bazę",
    "Database user" : "Duomenų bazės vartotojas",
    "Database password" : "Duomenų bazės slaptažodis",
    "Database name" : "Duomenų bazės pavadinimas",
    "Database tablespace" : "Duomenų bazės loginis saugojimas",
    "Database host" : "Duomenų bazės serveris",
    "Finish setup" : "Baigti diegimą",
    "Finishing …" : "Baigiama ...",
    "Log out" : "Atsijungti",
    "Search" : "Ieškoti",
    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
    "Please contact your administrator." : "Kreipkitės į savo sistemos administratorių.",
    "Log in" : "Prisijungti",
    "Alternative Logins" : "Alternatyvūs prisijungimai",
    "Use the following link to reset your password: {link}" : "Slaptažodio atkūrimui naudokite šią nuorodą: {link}",
    "New password" : "Naujas slaptažodis",
    "New Password" : "Naujas slaptažodis",
    "Reset password" : "Atkurti slaptažodį",
    "This ownCloud instance is currently in single user mode." : "Ši ownCloud sistema yra vieno naudotojo veiksenoje.",
    "This means only administrators can use the instance." : "Tai reiškia, kad tik administratorius gali naudotis sistema.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi jei šis pranešimas nedingsta arba jei jis pasirodė netikėtai.",
    "Thank you for your patience." : "Dėkojame už jūsų kantrumą.",
    "No valid crop data provided" : "Nėra galiojančių apkirpimo duomenų",
    "Crop is not square" : "Kirpimas ne kvadratas",
    "Could not reset password because the token is invalid" : "Nepavyko pakeisti slaptažodžio nes kodas neteisingas",
    "Could not reset password because the token expired" : "Nepavykos atkurti slaptažodžio nes kodas negalioja",
    "Checking updates of apps" : "Tikrina atnaujinimus programoms",
    "Remove link" : "Pašalinti nuorodą",
    "Create public link" : "Sukurti viešą nuorodą",
    "Copy to clipboard" : "Kopijuoti į talpyklę",
    "Anyone with the link has access to the file/folder" : "Kiekvienas turintis šią nuorodą gali pasiekti failą/katalogą",
    "Choose a password" : "Pasirinkite slaptažodį",
    "invisible" : "Nematomas",
    "Delete {link}" : "Trinti (link)",
    "unknown text" : "nežinomas tekstas",
    "Message: %s" : "Žinutė: %s",
    "Line: %s" : "Eilutė: %s",
    "Menu" : "Meniu",
    "Username or email" : "Vartotojas arba el. paštas",
    "Cancel login" : "Atšaukti prisijungimą",
    "Update needed" : "Reikalingas atnaujinimas",
    "Searching other places" : "Ieškoma kitose vietose",
    "See the documentation" : "Žiūrėti dokumentaciją",
    "Link name" : "Nuorodos pavadinimas",
    "An error occurred. Please contact your admin." : "Įvyko klaida. Susiekite su administratorium.",
    "%s password changed successfully" : "%sslaptažodis pakeistas",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "%s (3rdparty)" : "%s(trečios šalies)",
    "%s (incompatible)" : "%s(nesuderinama)",
    "{fileName} link" : "{fileName} nuoroda",
    "Hello {name}, the weather is {weather}" : "Labas (name), oras (weather)",
    "Hello {name}" : "Labas (name)",
    "new" : "naujas",
    "An error occurred." : "Įvyko klaida.",
    "Only %s is available." : "Tik %sgalima.",
    "Wrong password. Reset it?" : "Blogas slaptažodis. Pakeisti?",
    "Wrong password." : "Neteisingas slaptažodis.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: tikrina lentelę %s",
    "SQLite will be used as database." : "Bus naudojama SQLite bazė.",
    "Need help?" : "Reikia pagalbos?"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.7.0.tar.bz2: owncloud/core/l10n/lt_LT.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Pasirinkite failą.",
    "File is too big" : "Per didelis failas",
    "Invalid file provided" : "Netinkamas failas",
    "No image or file provided" : "Nenurodytas paveikslėlis ar failas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Netinkamas paveikslėlis",
    "An error occurred. Please contact your admin." : "Įvyko klaida. Susiekite su administratorium.",
    "No temporary profile picture available, try again" : "Nėra laikino profilio paveikslėlio, bandykite dar kartą",
    "No crop data provided" : "Nenurodyti apkirpimo duomenys",
    "No valid crop data provided" : "Nėra galiojančių apkirpimo duomenų",
    "Crop is not square" : "Kirpimas ne kvadratas",
    "Could not reset password because the token is invalid" : "Nepavyko pakeisti slaptažodžio nes kodas neteisingas",
    "Could not reset password because the token expired" : "Nepavykos atkurti slaptažodžio nes kodas negalioja",
    "%s password changed successfully" : "%sslaptažodis pakeistas",
    "%s password reset" : "%s slaptažodžio atnaujinimas",
    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atkūrimo laiško, susisiekite su administratoriumi.",
    "Download / View" : "Atsisiųsti / Peržiūrėti",
    "Download / View / Upload" : "Atsisiųsti / Peržiūrėti / Įkelti",
    "Preparing update" : "Ruošiamasi atnaujinimui",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Taisymo perspėjimas:",
    "Repair error: " : "Taisymo klaida:",
    "[%d / %d]: Checking table %s" : "[%d / %d]: tikrina lentelę %s",
    "Turned on maintenance mode" : "Įjungta priežiūros veiksena",
    "Turned off maintenance mode" : "Išjungta priežiūros veiksena",
    "Maintenance mode is kept active" : "Priežiūros veiksena yra aktyvi",
    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
    "Updated database" : "Atnaujinta duomenų bazė",
    "Checked database schema update" : "Tikrinama duomenų bazės struktūra",
    "Checking updates of apps" : "Tikrina atnaujinimus programoms",
    "Checked database schema update for apps" : "Tikrinama duomenų bazės struktūra įskiepiams",
    "Updated \"%s\" to %s" : "Atnaujinta \"%s\" į %s",
    "%s (3rdparty)" : "%s(trečios šalies)",
    "%s (incompatible)" : "%s(nesuderinama)",
    "Following apps have been disabled: %s" : "Išjungti įskiepiai: %s",
    "Already up to date" : "Jau naujausia",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sun." : "Sk.",
    "Mon." : "Pr.",
    "Tue." : "An.",
    "Wed." : "Tr.",
    "Thu." : "Kt.",
    "Fri." : "Pn.",
    "Sat." : "Št.",
    "Su" : "S",
    "Mo" : "P",
    "Tu" : "A",
    "We" : "T",
    "Th" : "K",
    "Fr" : "Pn",
    "Sa" : "Š",
    "January" : "Sausis",
    "February" : "Vasaris",
    "March" : "Kovas",
    "April" : "Balandis",
    "May" : "Gegužė",
    "June" : "Birželis",
    "July" : "Liepa",
    "August" : "Rugpjūtis",
    "September" : "Rugsėjis",
    "October" : "Spalis",
    "November" : "Lapkritis",
    "December" : "Gruodis",
    "Jan." : "Sau.",
    "Feb." : "Vas.",
    "Mar." : "Kov.",
    "Apr." : "Bal.",
    "May." : "Geg.",
    "Jun." : "Bir.",
    "Jul." : "Lie.",
    "Aug." : "Rugp.",
    "Sep." : "Rugs.",
    "Oct." : "Spa.",
    "Nov." : "Lap.",
    "Dec." : "Groud.",
    "Settings" : "Nustatymai",
    "Saving..." : "Saugoma...",
    "Dismiss" : "Atmesti",
    "seconds ago" : "prieš sekundę",
    "I know what I'm doing" : "Aš žinau ką darau",
    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas, susisiekite su administratoriumi.",
    "No" : "Ne",
    "Yes" : "Taip",
    "Choose" : "Pasirinkite",
    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
    "Ok" : "Gerai",
    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
    "read-only" : "tik skaitymui",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failas konfliktuoja","{count} failai konfliktuoja","{count} failų konfliktų","{count} failų konfliktų"],
    "One file conflict" : "Vienas failo konfliktas",
    "New Files" : "Naujas failas",
    "Already existing files" : "Egzistuojantys failai",
    "Which files do you want to keep?" : "Kuriuos failus norite laikyti?",
    "If you select both versions, the copied file will have a number added to its name." : "Jei pasirenkate abi versijas, nukopijuotas failas turės pridėtą numerį pavadinime.",
    "Cancel" : "Atšaukti",
    "Continue" : "Tęsti",
    "(all selected)" : "(visi pažymėti)",
    "({count} selected)" : "({count} pažymėtų)",
    "Error loading file exists template" : "Klaida įkeliant esančių failų ruošinį",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Shared" : "Dalinamasi",
    "Error" : "Klaida",
    "Error while sharing" : "Klaida, dalijimosi metu",
    "Error while unsharing" : "Klaida, kai atšaukiamas dalijimasis",
    "The public link will expire no later than {days} days after it is created" : "Vieša nuoroda galios ne mažiau kaip {days} dienas nuo sukūrimo",
    "Expiration" : "Galiojimo laikas",
    "Delete {link}" : "Trinti (link)",
    "Remove link" : "Pašalinti nuorodą",
    "Link" : "Nuoroda",
    "Create public link" : "Sukurti viešą nuorodą",
    "Edit" : "Redaguoti",
    "Remove" : "Pašalinti",
    "Copy to clipboard" : "Kopijuoti į talpyklę",
    "Anyone with the link has access to the file/folder" : "Kiekvienas turintis šią nuorodą gali pasiekti failą/katalogą",
    "Copied!" : "Nukopijuota!",
    "Choose a password" : "Pasirinkite slaptažodį",
    "Password required" : "Reikalingas slaptažodis",
    "Link name" : "Nuorodos pavadinimas",
    "Name" : "Pavadinimas",
    "Filename" : "Failo pavadinimas",
    "Password" : "Slaptažodis",
    "Share" : "Dalintis",
    "Save" : "Išsaugoti",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send link via email" : "Siųsti nuorodą el. paštu",
    "Shared with you and the group {group} by {owner}" : "Pasidalino su Jumis ir {group} grupe {owner}",
    "Shared with you by {owner}" : "Pasidalino su Jumis {owner}",
    "group" : "grupė",
    "notify by email" : "pranešti el. paštu",
    "Unshare" : "Nebesidalinti",
    "can share" : "gali dalintis",
    "can edit" : "gali redaguoti",
    "create" : "sukurti",
    "change" : "keisti",
    "delete" : "ištrinti",
    "access control" : "priėjimo kontrolė",
    "User" : "Naudotojas",
    "Group" : "Grupė",
    "Public Links" : "Viešos nuorodos",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Dalintis su vartotoju kitame ownCloud debesyje, sintaksė vartotojas@example.com/owncloud",
    "Share with users…" : "Dalintis su vartotojais...",
    "Share with users, groups or remote users…" : "Dalintis su vartotojais, grupėmis, ar nutolusiais vartotojais...",
    "Share with users or groups…" : "Dalintis su vartotojais arba grupėmis...",
    "Share with users or remote users…" : "Dalintis su vartotojais ar nutolusiais vartotojais...",
    "invisible" : "Nematomas",
    "Delete" : "Ištrinti",
    "Rename" : "Pervadinti",
    "The object type is not specified." : "Objekto tipas nenurodytas.",
    "Enter new" : "Įveskite naują",
    "Add" : "Pridėti",
    "Edit tags" : "Redaguoti žymes",
    "Error loading dialog template: {error}" : "Klaida įkeliant dialogo ruošinį: {error}",
    "No tags selected for deletion." : "Trynimui nepasirinkta jokia žymė.",
    "unknown text" : "nežinomas tekstas",
    "Hello world!" : "Sveikas pasauli!",
    "sunny" : "saulėta",
    "Hello {name}, the weather is {weather}" : "Labas (name), oras (weather)",
    "Hello {name}" : "Labas (name)",
    "new" : "naujas",
    "An error occurred." : "Įvyko klaida.",
    "Please reload the page." : "Prašome perkrauti puslapį.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Atnaujinimas buvo nesėkmingas. PApie tai prašome pranešti the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud bendruomenei</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Atnaujinimas buvo sėkmingas. Nukreipiame į jūsų ownCloud.",
    "Searching other places" : "Ieškoma kitose vietose",
    "Personal" : "Asmeniniai",
    "Users" : "Vartotojai",
    "Apps" : "Programos",
    "Admin" : "Administravimas",
    "Help" : "Pagalba",
    "Access forbidden" : "Priėjimas draudžiamas",
    "File not found" : "Failas nerastas",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Labas,\n\nInformuojame, kad %s pasidalino su Jumis %s.\nPažiūrėti tai: %s\n",
    "The share will expire on %s." : "Bendrinimo laikas baigsis %s.",
    "Cheers!" : "Sveikinimai!",
    "Internal Server Error" : "Vidinė serverio klaida",
    "Technical details" : "Techniniai duomenys",
    "Remote Address: %s" : "Nuotolinis adresas: %s",
    "Request ID: %s" : "Užklausos ID: %s",
    "Type: %s" : "Tipas: %s",
    "Code: %s" : "Kodas: %s",
    "Message: %s" : "Žinutė: %s",
    "File: %s" : "Failas: %s",
    "Line: %s" : "Eilutė: %s",
    "Trace" : "Sekti",
    "Imprint" : "Imprint",
    "Create an <strong>admin account</strong>" : "Sukurti <strong>administratoriaus paskyrą</strong>",
    "Username" : "Prisijungimo vardas",
    "Storage & database" : "Saugykla ir duomenų bazė",
    "Data folder" : "Duomenų katalogas",
    "Configure the database" : "Nustatyti duomenų bazę",
    "Only %s is available." : "Tik %sgalima.",
    "Database user" : "Duomenų bazės vartotojas",
    "Database password" : "Duomenų bazės slaptažodis",
    "Database name" : "Duomenų bazės pavadinimas",
    "Database tablespace" : "Duomenų bazės loginis saugojimas",
    "Database host" : "Duomenų bazės serveris",
    "SQLite will be used as database." : "Bus naudojama SQLite bazė.",
    "Finish setup" : "Baigti diegimą",
    "Finishing …" : "Baigiama ...",
    "Need help?" : "Reikia pagalbos?",
    "See the documentation" : "Žiūrėti dokumentaciją",
    "Menu" : "Meniu",
    "Log out" : "Atsijungti",
    "Search" : "Ieškoti",
    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
    "Please contact your administrator." : "Kreipkitės į savo sistemos administratorių.",
    "Login" : "Prisijungti",
    "Username or email" : "Vartotojas arba el. paštas",
    "Wrong password. Reset it?" : "Blogas slaptažodis. Pakeisti?",
    "Wrong password." : "Neteisingas slaptažodis.",
    "Alternative Logins" : "Alternatyvūs prisijungimai",
    "Use the following link to reset your password: {link}" : "Slaptažodio atkūrimui naudokite šią nuorodą: {link}",
    "New password" : "Naujas slaptažodis",
    "New Password" : "Naujas slaptažodis",
    "Reset password" : "Atkurti slaptažodį",
    "This ownCloud instance is currently in single user mode." : "Ši ownCloud sistema yra vieno naudotojo veiksenoje.",
    "This means only administrators can use the instance." : "Tai reiškia, kad tik administratorius gali naudotis sistema.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi jei šis pranešimas nedingsta arba jei jis pasirodė netikėtai.",
    "Thank you for your patience." : "Dėkojame už jūsų kantrumą.",
    "Cancel login" : "Atšaukti prisijungimą",
    "Update needed" : "Reikalingas atnaujinimas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
